with Ada.IO_Exceptions;
with Parse_File;

package body Configuration_Maps is
   procedure Close;

   ----------
   -- Load --
   ----------

   procedure Load
     (Obj : access T_Configuration_File_Descriptor;
      File : String;
      Type_File : T_Type_File) is
   begin
      Load (Obj, To_Unbounded_String (File), Type_File);
   end Load;

   procedure Load
     (Obj : access T_Configuration_File_Descriptor;
      File : Unbounded_String;
      Type_File : T_Type_File)
   is
      use Parse_File;
   begin
      Base_Maps.Clear (Obj.DB);
      Set_Type_File (Type_File);
      Set_File_Name (File);
      Init;
      declare
         Key : Unbounded_String;
         Val : Unbounded_String;
      begin
         loop
            begin
               Get_Next_Element (Key, Val);
               Base_Maps.Insert (Obj.DB, Key, Val);
            exception
               when Empty_Key =>           -- Reading a line without key
                  null;
               when Comment_Line_Found =>  -- Reading commentary line
                  null;
            end;
         end loop;
      exception -- End of the configuration file
         when Ada.IO_Exceptions.End_Error => null;
      end;
      Close;
   end Load;

   -----------
   -- Close --
   -----------

   procedure Close is
   begin
      Parse_File.Close;
   end Close;


   ---------
   -- Get --
   ---------

   function Get
     (Obj : access T_Configuration_File_Descriptor;
      Search_Key : Unbounded_String)
      return Unbounded_String
   is
      Ret : Unbounded_String;
   begin
      begin
         Ret := Base_Maps.Element (Obj.DB, Search_Key);
      exception
         when others => raise Key_Not_Found;
      end;
      return Ret;
   end Get;

   function Get (Obj : access T_Configuration_File_Descriptor;
                 Search_Key : Unbounded_String) return String is
   begin
      return To_String (Get (Obj, Search_Key));
   end Get;

   function Get (Obj : access T_Configuration_File_Descriptor;
                 Search_Key : String) return Unbounded_String is
   begin
      return Get (Obj, To_Unbounded_String (Search_Key));
   end Get;

   function Get (Obj : access T_Configuration_File_Descriptor;
                 Search_Key : String) return String is
   begin
      return To_String (Get (Obj, To_Unbounded_String (Search_Key)));
   end Get;
end Configuration_Maps;
