with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;

--  <description>
--  Defined the various types which will be converted by the print program
--  This program allows to convert a number in another base at base_2 to base_16
--  </description>
--  <group>Print</group>
--  <version>1.0.0</version>

package Print.Numeric is
   type T_Hexadecimal is range 0 .. 15;
   type T_Octal is range 0 .. 7;
   type T_Binary is range 0 .. 1;

   Wrong_Type : exception;

   type Base is (Base_2, Base_3, Base_4, Base_5, Base_6, Base_7, Base_8,
                 Base_9, Base_10, Base_11, Base_12, Base_13, Base_14, Base_15,
                 Base_16);

   function Number_To_String (N : Natural; B : Base) return String;
      --  <summary>Convert a number in another base with a base type and return a String</summary>
      --  <parameter name="N">A natural</parameter>
      --  <parameter name="B">A base</parameter>
      --  <exception>Wrong_Type</exception>
      --  <seealso>Base_To_String</seealso>
private
   function Base_To_String (N : Natural; Base : Natural)
                           return Unbounded_String;
      --  <summary>Convert a number in another bases with a divide wanted and the way back a String</summary>
      --  <parameter name="N">A natural</parameter>
      --  <parameter name="Base">A natural</parameter>
      --  <expection>Wrong_Type</exception>
      --  <seealso>Numeric_To_String</seealso>
   function Preformat (S : Unbounded_String; Width : Natural)
                      return Unbounded_String;
      --  <summary>Make a concatenate with number "0" and convert number allow to complete the Unbounded_String</summary>
      --  <parameter name="S">A extended string</parameter>
      --  <parameter name="Width">A natural</parameter>
      --  <exception>Wrong_type</exception>
      --  <seealso>Number_To_String</seealso>
   function Numeric_To_String (N : Natural) return Unbounded_String;
      --  <summary>Allows to eliminate a space when this function return a figure in Unbounded_String</summary>
      --  <parameter name="N">A natural</parameter>
      --  <exception>Wrong_Type</exception>
      --  <seealso>Nothing</seealso>
end Print.Numeric;
