--  <description>
--  Convert an unbounded_string in integer whether it is a decimal or hexadecimal value
--  </description>
--  <group>read</group>
--  <c_version>1.0.0</c_version>

with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;

package Read.Numeric is
   function Read_Hex (Val : Unbounded_String) return Integer;
   --  <summary>Convert an unbounded_string hexadecimal in integer value</summary>
   --  <parameter name="Val">An Unbounded_String</parameter>
   --  <exception>Wrong_Type when that not a good hexadecimal argument</exception>
   --  <seealso>Read_Hex_Interne</seealso>

   function Read_Dec (Val : Unbounded_String) return Integer;
   --  <summary>Convert an unbounded_string decimal in integer value</summary>
   --  <parameter name="Val">An unbounded_String</parameter>
   --  <exception>Wrong_Type</exception>
   --  <seealso>Read_Dec_Interne</seealso>

   function Read_Hex_Dec (Val : Unbounded_String) return Integer;
   --  <summary>Use Read_Hex and Read_Dec for make only one function</summary>
   --  <parameter name="Val">An Unbounded_String</parameter>
   --  <exception>Wrong_Type</exception>
   --  <seealso>Read_Hex and Read_Dec</seealso>

private

   function Read_Hex_Interne (Val : Unbounded_String) return Integer;
   --  <summary>Execution function to convert a hexadecimal unbounded_string in integer</summary>
   --  <parameter name="Val">An Unbounded_String</parameter>
   --  <exception>Constaint_Error when a argument don't begin with "0x" or "0X"</exception>
   --  <seealso>nothing</seealso>

   function Read_Dec_Interne (Val : Unbounded_String) return Integer;
   --  <summary>Execution function to convert a decimal unbounded_string in integer</summary>
   --  <parameter name="Val">An Unbounded_String</parameter>
   --  <exception>Wrong_Type when that not a good decimal argument</exception>
   --  <seealso>nothing</seealso>

end Read.Numeric;
