with Print.Numeric.Binary.Unit_Test;
with AUnit.Assertions;

package body Print.Numeric.Binary.Unit_Test is

   function Equivalent_Values (Val1, Val2 : String) return Boolean is
   begin
      return Val1 = Val2;
   end Equivalent_Values;

   procedure Test_Format_0 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "1111 1111";
      Key2 : constant String := Format ("11111111");
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertion string '11111111' = string '1111 1111'");
   end Test_Format_0;

   procedure Test_Format_1 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "101 0101 0101";
      Key2 : constant String := Format ("10101010101");
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string '10101010101' = string '101 0101 0101'");
   end Test_Format_1;

   procedure Test_Format_2 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := " ";
      Key2 : constant String := Format (" ");
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string ' ' = string ' '");
   end Test_Format_2;

   procedure Test_Binary_To_String_0 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "00";
      Key2 : constant String := Binary_To_String (Natural'First, 2);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string 00 = string 'Natural'First and 2'");
   end Test_Binary_To_String_0;

   procedure Test_Binary_To_String_1 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "0001";
      Key2 : constant String := Binary_To_String (1, 4);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string 0001 = string '1 and 4'");
   end Test_Binary_To_String_1;

   procedure Test_Binary_To_String_2 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "0000 0010";
      Key2 : constant String := Binary_To_String (2, 8);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string 0000 0010 = string '2 and 8'");
   end Test_Binary_To_String_2;

   procedure Test_Binary_To_String_3 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "00 0000 0011";
      Key2 : constant String := Binary_To_String (3, 10);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string 00 0000 0011 = string '3 and 10'");
   end Test_Binary_To_String_3;

   procedure Test_Binary_To_String_4 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "100 0000";
      Key2 : constant String := Binary_To_String (64, 4);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string 100 0000 = string '64 and 4'");
   end Test_Binary_To_String_4;

   procedure Test_Binary_To_String_5 (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "111 1111 1111 1111 1111 1111 1111 1111";
      Key2 : constant String := Binary_To_String (Natural'Last, 8);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string '111 1111 1111 1111 1111 1111 1111 1111' = string 'Natural'Last and 8'");
   end Test_Binary_To_String_5;




   procedure Test_Binary_To_String_first (T : in out AUnit.Test_Cases.Test_Case'Class) is
      pragma Unreferenced (T);
      Key1 : constant String := "1010";
      Key2 : constant String := Binary_To_String (10, Natural'First);
   begin
      AUnit.Assertions.Assert (Equivalent_Values (Key1, Key2),
			       "Assertions string '1010' = string '10 and Natural'first'");
   end Test_Binary_To_String_first;



   procedure Register_Tests (T : in out T_Print_Test_Case) is
      use AUnit.Test_Cases.Registration;
   begin

      Register_Routine (T, Test_Format_0'Access, "Format (11111111) = 1111 1111");
      Register_Routine (T, Test_Format_1'Access, "Format (10101010101) = 101 0101 0101");
      Register_Routine (T, Test_Format_2'Access, "Format ( ) = ' '");

      Register_Routine (T, Test_Binary_To_String_0'Access, "Binary_To_String (Natural'First, 2) = 00");
      Register_Routine (T, Test_Binary_To_String_1'Access, "Binary_To_String (1, 4) = 0001");
      Register_Routine (T, Test_Binary_To_String_2'Access, "Binary_To_String (2, 8) = 0000 0010");
      Register_Routine (T, Test_Binary_To_String_3'Access, "Binary_To_String (3, 10) = 00 0000 0011");
      Register_Routine (T, Test_Binary_To_String_4'Access, "Binary_To_String (64, 4) = 100 0000");
      Register_Routine (T, Test_Binary_To_String_5'Access, "Binary_To_String (Natural'Last, 8) = 111 1111 1111 1111 1111 1111 1111 1111");
      Register_Routine (T, Test_Binary_To_String_first'Access, "Binary_To_String (10, Natural'first) = 1010");
   end Register_Tests;


   function Name (T : T_Print_Test_Case) return Message_String is
      pragma Unreferenced (T);
   begin
      return new String'("print module tests");
   end Name;

end Print.Numeric.Binary.Unit_Test;
